==> beeai_server-0.0.8.tar.gz: beeai_server-0.0.8/src/beeai_server/configuration.py <==
# Copyright 2025 IBM Corp.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import base64
import logging
from collections import defaultdict
from functools import cache
from pathlib import Path

from beeai_server.utils.github import GithubUrl
from pydantic import BaseModel, Field, ValidationError, field_validator, model_validator
from pydantic_settings import BaseSettings, SettingsConfigDict


class LoggingConfiguration(BaseModel):
    level: int = logging.INFO
    level_managed_provider: int = logging.INFO
    level_uvicorn: int = Field(default=logging.FATAL, validate_default=True)

    @model_validator(mode="after")
    def level_uvicorn_validator(self):
        if self.level == logging.DEBUG:
            self.level_uvicorn = logging.WARNING
        return self

    @field_validator("level", "level_uvicorn", "level_managed_provider", mode="before")
    def validate_level(cls, v: str | int | None):
        return v if isinstance(v, int) else logging.getLevelNamesMapping()[v]


class OCIRegistryConfiguration(BaseModel, extra="allow"):
    username: str | None = None
    password: str | None = None
    insecure: bool = False

    @property
    def protocol(self):
        return "http" if self.insecure else "https"

    @property
    def basic_auth_str(self) -> str | None:
        if self.username and self.password:
            return base64.b64encode(f"{self.username}:{self.password}".encode()).decode()
        return None


class AgentRegistryConfiguration(BaseModel):
    location: GithubUrl = GithubUrl(root="https://github.com/i-am-bee/beeai@release-v0.0.9#path=agent-registry.yaml")
    preinstall: bool = True


class Configuration(BaseSettings):
    model_config = SettingsConfigDict(env_file=".env", env_file_encoding="utf-8", env_nested_delimiter="__")

    logging: LoggingConfiguration = LoggingConfiguration()
    agent_registry: AgentRegistryConfiguration = AgentRegistryConfiguration()
    oci_registry: dict[str, OCIRegistryConfiguration] = Field(default_factory=dict)

    provider_config_path: Path = Path.home() / ".beeai" / "providers.yaml"
    telemetry_config_path: Path = Path.home() / ".beeai" / "telemetry.yaml"
    env_path: Path = Path.home() / ".beeai" / ".env"
    cache_dir: Path = Path.home() / ".beeai" / "cache"
    port: int = 8333
    collector_port: int = 8335
    docker_host: str | None = None
    force_lima: bool = False
    autostart_providers: bool = False

    @model_validator(mode="after")
    def _oci_registry_defaultdict(self):
        oci_registry = defaultdict(OCIRegistryConfiguration)
        oci_registry.update(self.oci_registry)
        self.oci_registry = oci_registry
        return self


@cache
def get_configuration() -> Configuration:
    """Get cached configuration"""
    try:
        return Configuration()
    except ValidationError as ex:
        from beeai_server.logging_config import configure_logging

        configure_logging(configuration=LoggingConfiguration(level=logging.ERROR))

        logging.error(f"Improperly configured, Error: {ex!r}")
        raise ValueError("Improperly configured, make sure to supply all required variables") from ex

==> beeai_server-0.0.10.tar.gz: beeai_server-0.0.10/src/beeai_server/configuration.py <==
# Copyright 2025 IBM Corp.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import base64
import logging
from collections import defaultdict
from functools import cache
from pathlib import Path

from beeai_server.utils.github import GithubUrl
from pydantic import BaseModel, Field, ValidationError, field_validator, model_validator
from pydantic_settings import BaseSettings, SettingsConfigDict


class LoggingConfiguration(BaseModel):
    level: int = logging.INFO
    level_managed_provider: int = logging.INFO
    level_uvicorn: int = Field(default=logging.FATAL, validate_default=True)

    @model_validator(mode="after")
    def level_uvicorn_validator(self):
        if self.level == logging.DEBUG:
            self.level_uvicorn = logging.WARNING
        return self

    @field_validator("level", "level_uvicorn", "level_managed_provider", mode="before")
    def validate_level(cls, v: str | int | None):
        return v if isinstance(v, int) else logging.getLevelNamesMapping()[v]


class OCIRegistryConfiguration(BaseModel, extra="allow"):
    username: str | None = None
    password: str | None = None
    insecure: bool = False

    @property
    def protocol(self):
        return "http" if self.insecure else "https"

    @property
    def basic_auth_str(self) -> str | None:
        if self.username and self.password:
            return base64.b64encode(f"{self.username}:{self.password}".encode()).decode()
        return None


class AgentRegistryConfiguration(BaseModel):
    location: GithubUrl = GithubUrl(root="https://github.com/i-am-bee/beeai@release-v0.0.10#path=agent-registry.yaml")
    preinstall: bool = True


class Configuration(BaseSettings):
    model_config = SettingsConfigDict(env_file=".env", env_file_encoding="utf-8", env_nested_delimiter="__")

    logging: LoggingConfiguration = LoggingConfiguration()
    agent_registry: AgentRegistryConfiguration = AgentRegistryConfiguration()
    oci_registry: dict[str, OCIRegistryConfiguration] = Field(default_factory=dict)

    provider_config_path: Path = Path.home() / ".beeai" / "providers.yaml"
    telemetry_config_dir: Path = Path.home() / ".beeai" / "telemetry"
    env_path: Path = Path.home() / ".beeai" / ".env"
    cache_dir: Path = Path.home() / ".beeai" / "cache"
    port: int = 8333
    collector_port: int = 8335
    docker_host: str | None = None
    force_lima: bool = False
    autostart_providers: bool = False

    @model_validator(mode="after")
    def _oci_registry_defaultdict(self):
        oci_registry = defaultdict(OCIRegistryConfiguration)
        oci_registry.update(self.oci_registry)
        self.oci_registry = oci_registry
        return self


@cache
def get_configuration() -> Configuration:
    """Get cached configuration"""
    try:
        return Configuration()
    except ValidationError as ex:
        from beeai_server.logging_config import configure_logging

        configure_logging(configuration=LoggingConfiguration(level=logging.ERROR))

        logging.error(f"Improperly configured, Error: {ex!r}")
        raise ValueError("Improperly configured, make sure to supply all required variables") from ex
